==> jc-1.4.0.tar.gz: polyglot/lex/CharacterLiteral.h <==
// public class polyglot.lex.CharacterLiteral

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class eb653821361c5947 polyglot_lex_CharacterLiteral
// @dep_class 923d72acc1d3eef7 polyglot_lex_Literal
// @dep_class 28b2d50426072b60 polyglot_lex_Token

// header file dependencies
// @dep_header polyglot_lex_Literal

#include "polyglot/lex/Literal.h"

#ifndef _JC_polyglot_lex_CharacterLiteral_H_
#define _JC_polyglot_lex_CharacterLiteral_H_

// Forward structure declarations
struct _jc_java_lang_Character$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_lex_CharacterLiteral$sub_refs	_jc_polyglot_lex_CharacterLiteral$sub_refs;
typedef struct _jc_polyglot_lex_CharacterLiteral$sub_nonrefs	_jc_polyglot_lex_CharacterLiteral$sub_nonrefs;
typedef struct _jc_polyglot_lex_CharacterLiteral$refs	_jc_polyglot_lex_CharacterLiteral$refs;
typedef struct _jc_polyglot_lex_CharacterLiteral$nonrefs	_jc_polyglot_lex_CharacterLiteral$nonrefs;
typedef struct _jc_polyglot_lex_CharacterLiteral$object	_jc_polyglot_lex_CharacterLiteral$object;

typedef const struct _jc_polyglot_lex_CharacterLiteral$vmethods	_jc_polyglot_lex_CharacterLiteral$vmethods;
typedef const struct _jc_polyglot_lex_CharacterLiteral$vtable	_jc_polyglot_lex_CharacterLiteral$vtable;
typedef const struct _jc_polyglot_lex_CharacterLiteral$vtype	_jc_polyglot_lex_CharacterLiteral$vtype;

// Constructors
extern void _jc_polyglot_lex_CharacterLiteral$method$_init$6a31d0c19b8e9d4d(_jc_env *, struct _jc_polyglot_lex_CharacterLiteral$object *, struct _jc_polyglot_util_Position$object *, jchar, jint);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_polyglot_lex_CharacterLiteral$method$getEscapedValue$f7fb28aea6449fb4(_jc_env *, struct _jc_polyglot_lex_CharacterLiteral$object *);
extern struct _jc_java_lang_Character$object *_jc_polyglot_lex_CharacterLiteral$method$getValue$b800b17f2b205f38(_jc_env *, struct _jc_polyglot_lex_CharacterLiteral$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_lex_CharacterLiteral$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_lex_CharacterLiteral$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_lex_CharacterLiteral$method_info$getEscapedValue$f7fb28aea6449fb4;
extern _jc_method _jc_polyglot_lex_CharacterLiteral$method_info$getValue$b800b17f2b205f38;
extern _jc_method _jc_polyglot_lex_CharacterLiteral$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_lex_CharacterLiteral$vmethods {
	struct _jc_java_lang_String$object	*(*getEscapedValue$f7fb28aea6449fb4)(_jc_env *, struct _jc_polyglot_lex_CharacterLiteral$object *);
	struct _jc_java_lang_Character$object	*(*getValue$b800b17f2b205f38)(_jc_env *, struct _jc_polyglot_lex_CharacterLiteral$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_lex_CharacterLiteral$object *);
};

// Vtable
struct _jc_polyglot_lex_CharacterLiteral$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_lex_Token$vmethods	polyglot_lex_Token;
	_jc_polyglot_lex_Literal$vmethods	polyglot_lex_Literal;
	_jc_polyglot_lex_CharacterLiteral$vmethods	polyglot_lex_CharacterLiteral;
};

// Vtype
struct _jc_polyglot_lex_CharacterLiteral$vtype {
	_jc_type			type;
	_jc_polyglot_lex_CharacterLiteral$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_lex_CharacterLiteral$sub_refs {
	struct _jc_java_lang_Character$object	*val;
};

// Reference instance fields (object)
struct _jc_polyglot_lex_CharacterLiteral$refs {
    _jc_polyglot_lex_CharacterLiteral$sub_refs	polyglot_lex_CharacterLiteral;
    _jc_polyglot_lex_Literal$sub_refs	polyglot_lex_Literal;
    _jc_polyglot_lex_Token$sub_refs	polyglot_lex_Token;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_lex_CharacterLiteral$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_lex_CharacterLiteral$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_lex_Token$sub_nonrefs	polyglot_lex_Token;
    _jc_polyglot_lex_Literal$sub_nonrefs	polyglot_lex_Literal;
    _jc_polyglot_lex_CharacterLiteral$sub_nonrefs	polyglot_lex_CharacterLiteral;
};

// Object instance structure
struct _jc_polyglot_lex_CharacterLiteral$object {
	_jc_polyglot_lex_CharacterLiteral$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_lex_CharacterLiteral$vtype	*vtype;
	_jc_polyglot_lex_CharacterLiteral$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_lex_CharacterLiteral$vtype _jc_polyglot_lex_CharacterLiteral$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_lex_CharacterLiteral, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_lex_CharacterLiteral$class_object;

#endif	/* _JC_polyglot_lex_CharacterLiteral_H_ */

==> jc-1.4.6.tar.gz: polyglot/lex/CharacterLiteral.h <==
// public class polyglot.lex.CharacterLiteral

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class eb653821361c5947 polyglot_lex_CharacterLiteral
// @dep_class 923d72acc1d3eef7 polyglot_lex_Literal
// @dep_class 28b2d50426072b60 polyglot_lex_Token

// header file dependencies
// @dep_header polyglot_lex_Literal

#include "polyglot/lex/Literal.h"

#ifndef _JC_polyglot_lex_CharacterLiteral_H_
#define _JC_polyglot_lex_CharacterLiteral_H_

// Forward structure declarations
struct _jc_java_lang_Character$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_lex_CharacterLiteral$sub_refs	_jc_polyglot_lex_CharacterLiteral$sub_refs;
typedef struct _jc_polyglot_lex_CharacterLiteral$sub_nonrefs	_jc_polyglot_lex_CharacterLiteral$sub_nonrefs;
typedef struct _jc_polyglot_lex_CharacterLiteral$refs	_jc_polyglot_lex_CharacterLiteral$refs;
typedef struct _jc_polyglot_lex_CharacterLiteral$nonrefs	_jc_polyglot_lex_CharacterLiteral$nonrefs;
typedef struct _jc_polyglot_lex_CharacterLiteral$object	_jc_polyglot_lex_CharacterLiteral$object;

typedef const struct _jc_polyglot_lex_CharacterLiteral$vmethods	_jc_polyglot_lex_CharacterLiteral$vmethods;
typedef const struct _jc_polyglot_lex_CharacterLiteral$vtable	_jc_polyglot_lex_CharacterLiteral$vtable;
typedef const struct _jc_polyglot_lex_CharacterLiteral$vtype	_jc_polyglot_lex_CharacterLiteral$vtype;

// Constructors
extern void _jc_polyglot_lex_CharacterLiteral$method$_init$6a31d0c19b8e9d4d(_jc_env *, struct _jc_polyglot_lex_CharacterLiteral$object *, struct _jc_polyglot_util_Position$object *, jchar, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_polyglot_lex_CharacterLiteral$method$getEscapedValue$f7fb28aea6449fb4(_jc_env *, struct _jc_polyglot_lex_CharacterLiteral$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Character$object *_jc_polyglot_lex_CharacterLiteral$method$getValue$b800b17f2b205f38(_jc_env *, struct _jc_polyglot_lex_CharacterLiteral$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_lex_CharacterLiteral$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_lex_CharacterLiteral$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_lex_CharacterLiteral$method_info$getEscapedValue$f7fb28aea6449fb4;
extern _jc_method _jc_polyglot_lex_CharacterLiteral$method_info$getValue$b800b17f2b205f38;
extern _jc_method _jc_polyglot_lex_CharacterLiteral$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_lex_CharacterLiteral$vmethods {
	struct _jc_java_lang_String$object	*(*getEscapedValue$f7fb28aea6449fb4)(_jc_env *, struct _jc_polyglot_lex_CharacterLiteral$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Character$object	*(*getValue$b800b17f2b205f38)(_jc_env *, struct _jc_polyglot_lex_CharacterLiteral$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_lex_CharacterLiteral$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_lex_CharacterLiteral$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_lex_Token$vmethods	polyglot_lex_Token;
	_jc_polyglot_lex_Literal$vmethods	polyglot_lex_Literal;
	_jc_polyglot_lex_CharacterLiteral$vmethods	polyglot_lex_CharacterLiteral;
};

// Vtype
struct _jc_polyglot_lex_CharacterLiteral$vtype {
	_jc_type			type;
	_jc_polyglot_lex_CharacterLiteral$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_lex_CharacterLiteral$sub_refs {
	struct _jc_java_lang_Character$object	*val;
};

// Reference instance fields (object)
struct _jc_polyglot_lex_CharacterLiteral$refs {
    _jc_polyglot_lex_CharacterLiteral$sub_refs	polyglot_lex_CharacterLiteral;
    _jc_polyglot_lex_Literal$sub_refs	polyglot_lex_Literal;
    _jc_polyglot_lex_Token$sub_refs	polyglot_lex_Token;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_lex_CharacterLiteral$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_lex_CharacterLiteral$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_lex_Token$sub_nonrefs	polyglot_lex_Token;
    _jc_polyglot_lex_Literal$sub_nonrefs	polyglot_lex_Literal;
    _jc_polyglot_lex_CharacterLiteral$sub_nonrefs	polyglot_lex_CharacterLiteral;
};

// Object instance structure
struct _jc_polyglot_lex_CharacterLiteral$object {
	_jc_polyglot_lex_CharacterLiteral$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_lex_CharacterLiteral$vtype	*vtype;
	_jc_polyglot_lex_CharacterLiteral$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_lex_CharacterLiteral$vtype _jc_polyglot_lex_CharacterLiteral$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_lex_CharacterLiteral, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_lex_CharacterLiteral$class_object;

#endif	/* _JC_polyglot_lex_CharacterLiteral_H_ */
